@@ -896,8 +896,15 @@ def build(
         if code_generation_config["generateYamlInterfaceFile"]:
             zc_core = ZCCore(build_cfg, unit_cfg)
             zc_dids = ZCDIDs(build_cfg, unit_cfg)
+            LOG.info("******************************************************")
+            LOG.info("Start generating NVMDefinitions")
+            start_time = time.time()
             project_nvm_defintions = unit_cfg.get_per_cfg_unit_cfg().get("nvm", {})
             zc_nvm = ZCNVMDef(build_cfg, unit_cfg, project_nvm_defintions)
+            LOG.info(
+                "Finished generating NVMDefinitions (in %4.2f s)", time.time() - start_time
+            )
+            LOG.info("******************************************************")
             axis_data = merged_a2l.get_characteristic_axis_data()
             composition_yaml = CompositionYaml(
                 build_cfg,
@@ -909,7 +916,6 @@ def build(
                 axis_data,
                 udt.get_enumerations()
             )
-            LOG.info("******************************************************")
             composition_yaml.generate_yaml()
             LOG.info("******************************************************")
             LOG.info("Generating Core header")
