@@ -642,6 +642,9 @@ class ZCDIDs(ProblemLogger):
             self.critical(f'DID {did} not defined in project diagnostics yaml file.')
 
         for did, did_data in yaml_dids.items():
+            if did_data.get('manual', False):
+                self._valid_dids[did] = {k: v for k, v in did_data.items() if k != "manual"}
+                continue
             if did not in self.project_dids:
                 self.warning(f'Ignoring DID {did}, not defined in any model.')
                 continue
@@ -779,6 +782,10 @@ class ZCDIDs(ProblemLogger):
         """Generate required DID API files.
         Only use for some projects, which doesn't copy static code."""
         if self.valid_dids is None:
+            includeDiagnostics = self._build_cfg.get_composition_config("includeDiagnostics")
+            if includeDiagnostics in ["manual", "manual_dids"]:
+                self.warning(f'includeDiagnostics is set to {includeDiagnostics}, not generating DID files.')
+                return
             self.critical('Valid DIDs not set. Cannot generate DID files.')
             return
 
