@@ -15,13 +15,15 @@ import time
 
 my_system = platform.system()
 if my_system == "Darwin":
-    MATLAB_BIN = os.environ.get("MatInstl2017", "/Applications/MATLAB_R2020a.app/bin/matlab")
+    MATLAB_BIN = os.environ.get(
+        "MatInstl",
+        os.environ.get("MatInstl2017", "/Applications/MATLAB_R2020a.app/bin/matlab")
+    )
 elif my_system == "Linux":
-    MATLAB_BIN = os.environ.get("MatInstl2017", "/usr/local/MATLAB/R2017b/bin/matlab")
+    MATLAB_BIN = os.environ.get("MatInstl", os.environ.get("MatInstl2017", "/usr/local/MATLAB/R2017b/bin/matlab"))
 else:
     from . import pt_win32
-
-    MATLAB_BIN = os.environ.get("MatInstl2017", "C:\\MATLABR2017b_x64\\bin\\matlab.exe")
+    MATLAB_BIN = os.environ.get("MatInstl", os.environ.get("MatInstl2017", "C:\\MATLABR2017b_x64\\bin\\matlab.exe"))
 
 LOGGER = logging.getLogger(__name__)
 logging.basicConfig(level=logging.INFO)
