@@ -35,14 +35,6 @@ class ZoneControllerCalibration(ProblemLogger):
         self.trigger_read_rte_cdata_signal_name = self.trigger_read_rte_cdata_signal['name_template'].format(
             swc_name=self.swc_name
         )
-        if self.trigger_read_rte_cdata_signal_name in self.calibration_variables:
-            self.critical(f'Signal {self.trigger_read_rte_cdata_signal_name} already defined in project.')
-        self.calibration_variables.update({
-            self.trigger_read_rte_cdata_signal_name: {
-                "type": self.trigger_read_rte_cdata_signal['data_type'],
-                "width": 1,
-            }
-        })
 
     def _get_header_guard(self):
         header_guard_tmp = Path(self.calibration_interface_header).stem
