@@ -65,6 +65,12 @@ class CompositionYaml(ProblemLogger):
                 self.include_calibration_interface_files = False
         if self.include_calibration_interface_files:
             trigger_read_rte_cdata_signal_name = self._get_calibration_trigger_signal_name(calibration_variables)
+            self.cal_class_info["tl"]["class_info"].update({
+                trigger_read_rte_cdata_signal_name: {
+                    "type": ZCC.trigger_read_rte_cdata_signal['data_type'],
+                    "width": 1,
+                }
+            })
             self.cal_class_info["autosar"]["class_info"].update(
                 {
                     trigger_read_rte_cdata_signal_name: {
@@ -88,30 +94,33 @@ class CompositionYaml(ProblemLogger):
             return float(value_str[:-1])
         return int(value_str)
 
-    @staticmethod
-    def _prepare_for_xml(string):
+    def _prepare_for_xml(self, signal_name, string):
         """Prepare a string for XML serialization.
 
         Args:
+            signal_name (str): The name of the signal.
             string (str): The string to prepare.
         Returns:
             xml_string (str): The prepared string.
         """
-        limited_string = string[:255]
-        no_line_breaks_string = "".join(limited_string.splitlines())
-        xml_string = scalarstring.DoubleQuotedScalarString(
-            no_line_breaks_string.replace(
-                "&", "&amp;"
-            ).replace(
-                "<", "&lt;"
-            ).replace(
-                ">", "&gt;"
-            ).replace(
-                "'", "&apos;"
-            ).replace(
-                '"', "&quot;"
-            )
-        )
+        illegal_xml_characters = {
+            "&": "&amp;",  # needs to be first in list
+            "<": "&lt;",
+            ">": "&gt;",
+            "'": "&apos;",
+            '"': "&quot;"
+        }
+        xml_string_tmp = "".join(string.splitlines())
+        for char, replacement in illegal_xml_characters.items():
+            xml_string_tmp = xml_string_tmp.replace(char, replacement)
+        if len(xml_string_tmp) > 255:
+            self.warning(f"Converted description for {signal_name} exceeds 255 characters and will be truncated.")
+            for replacement in illegal_xml_characters.values():
+                found = xml_string_tmp.find(replacement, 255-len(replacement), 255+len(replacement))
+                if found < 255 and found + len(replacement) > 255:
+                    xml_string_tmp = xml_string_tmp[:found]
+            xml_string_tmp = xml_string_tmp[:255]  # Since "found" is always < 255 this is safe
+        xml_string = scalarstring.DoubleQuotedScalarString(xml_string_tmp)
         return xml_string
 
     def get_base_data_types(self):
@@ -577,20 +586,28 @@ class CompositionYaml(ProblemLogger):
         swcs[software_component_name]["asil"] = self.build_cfg.get_composition_config("asil")
         swcs[software_component_name]["secure"] = self.build_cfg.get_composition_config("secure")
         swcs[software_component_name]["runnables"] = self._get_runnable_info()
-        if self.build_cfg.get_composition_config("includeShared"):
+        if self.build_cfg.get_composition_config("includeShared") is True:
             swcs[software_component_name]["shared"] = self.cal_class_info["autosar"]["class_info"]
             for variable_name, variable_info in self.composition_spec.get("shared", {}).items():
                 if variable_name in swcs[software_component_name]["shared"]:
                     self.critical("Shared variable %s already defined in project.", variable_name)
                 else:
                     swcs[software_component_name]["shared"][variable_name] = variable_info
-        if self.build_cfg.get_composition_config("includeStatic"):
+        elif self.build_cfg.get_composition_config("includeShared") == "manual":
+            swcs[software_component_name]["shared"] = {}
+            for variable_name, variable_info in self.composition_spec.get("shared", {}).items():
+                swcs[software_component_name]["shared"][variable_name] = variable_info
+        if self.build_cfg.get_composition_config("includeStatic") is True:
             swcs[software_component_name]["static"] = self.meas_class_info["autosar"]["class_info"]
             for variable_name, variable_info in self.composition_spec.get("static", {}).items():
                 if variable_name in swcs[software_component_name]["static"]:
                     self.critical("Static variable %s already defined in project.", variable_name)
                 else:
                     swcs[software_component_name]["static"][variable_name] = variable_info
+        elif self.build_cfg.get_composition_config("includeStatic") == "manual":
+            swcs[software_component_name]["static"] = {}
+            for variable_name, variable_info in self.composition_spec.get("static", {}).items():
+                swcs[software_component_name]["static"][variable_name] = variable_info
         swcs[software_component_name]["ports"] = self._get_ports_info()
         if self.composition_spec.get("io") is not None:
             swcs[software_component_name]["io"] = self.composition_spec["io"]
@@ -601,7 +618,7 @@ class CompositionYaml(ProblemLogger):
         if self.build_cfg.get_composition_config("includeNvm"):
             swcs[software_component_name]["nv-needs"] = nvm_info
             nvm_data_types = nvm_data_types_tmp
-            if self.build_cfg.get_composition_config("includeStatic"):
+            if self.build_cfg.get_composition_config("includeStatic") is True:
                 swcs[software_component_name]["static"].update(static_variables)
         else:
             nvm_data_types = {}
@@ -688,6 +705,9 @@ class CompositionYaml(ProblemLogger):
         """
         if info["type"] in self.enums.keys():
             return class_info, data_types
+
+        includeSharedSwAddrMethod = self.build_cfg.get_composition_config("includeSharedSwAddrMethod")
+        isReadOnly = "CVC_DISP" in info["class"] or info["class"] == "CVC_EXT"
         if "Bool" in info["type"]:
             upper = 1
             lower = 0
@@ -696,14 +716,19 @@ class CompositionYaml(ProblemLogger):
             base_type_upper = self.data_types[info["type"]]["limits"]["upper"]
             lower = info["min"] if info["min"] != "-" else base_type_lower
             upper = info["max"] if info["max"] != "-" else base_type_upper
+
         if not isinstance(info["width"], list):
             class_info[signal_name] = {
                 "type": info["type"],
-                "access": "READ-ONLY" if "CVC_DISP" in info["class"] or info["class"] == "CVC_EXT" else "READ-WRITE",
+                "access": "READ-ONLY" if isReadOnly else "READ-WRITE",
                 "init": self.calibration_init_values.get(signal_name, max(min(0, upper), lower)),
             }
             if info["description"]:
-                class_info[signal_name]["longname"] = self._prepare_for_xml(info["description"])
+                class_info[signal_name]["longname"] = self._prepare_for_xml(signal_name, info["description"])
+            if info["unit"] and info["unit"] != "-":
+                class_info[signal_name]["unit"] = info["unit"]
+            if includeSharedSwAddrMethod and not isReadOnly:
+                class_info[signal_name]["swAddrMethod"] = f"VCC_CALIBRATION_{signal_name.split('_')[0]}"
             return class_info, data_types
 
         if isinstance(lower, list) or isinstance(upper, list):
@@ -808,10 +833,12 @@ class CompositionYaml(ProblemLogger):
         new_data_type[new_data_type_name] = new_data_type_data
         class_info[signal_name] = {
             "type": new_data_type_name,
-            "access": "READ-ONLY" if "CVC_DISP" in info["class"] else "READ-WRITE",
+            "access": "READ-ONLY" if isReadOnly else "READ-WRITE",
             "init": init,
         }
         if info["description"]:
-            class_info[signal_name]["longname"] = self._prepare_for_xml(info["description"])
+            class_info[signal_name]["longname"] = self._prepare_for_xml(signal_name, info["description"])
+        if includeSharedSwAddrMethod and not isReadOnly:
+            class_info[signal_name]["swAddrMethod"] = f"VCC_CALIBRATION_{signal_name.split('_')[0]}"
         data_types = {**data_types, **new_data_type}
         return class_info, data_types
